# Version v0.17.14

This release marks a minor version bump to v0.17.14. It includes routine maintenance and preparation for upcoming features.

## New Features

- Version update to 0.17.14 for system consistency and future updates (c475320) (github-actions)

## Bug Fixes

There are no bug fixes in this release.

## Deprecations

There are no deprecations in this release.
